package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum AsynchroneRequestStatus implements SwigIntegerValue {

	COMPLETE("GARIO_COMPLETE"),
	ERROR("GARIO_ERROR"),
	PENDING("GARIO_PENDING"),
	UPDATE("GARIO_UPDATE");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private AsynchroneRequestStatus(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case COMPLETE:
				return gdalconst.GARIO_COMPLETE;
			case ERROR:
				return gdalconst.GARIO_ERROR;
			case PENDING:
				return gdalconst.GARIO_PENDING;
			case UPDATE:
				return gdalconst.GARIO_UPDATE;
			default:
				return gdalconst.GARIO_ERROR;
		}
	}

	/**
	 * Get this AsynchroneRequestStatus by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the AsynchroneRequestStatus which corresponds to the name.
	 */
	public static AsynchroneRequestStatus getConstantByName(String name) {
		for (AsynchroneRequestStatus asynchroneRequestStatus : AsynchroneRequestStatus.values()) {
			if (name.equalsIgnoreCase(asynchroneRequestStatus.name)) {
				return asynchroneRequestStatus;
			}
		}

		return null;
	}

	/**
	 * Get this AsynchroneRequestStatus by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the AsynchroneRequestStatus which corresponds to the value.
	 */
	public static AsynchroneRequestStatus getConstantByValue(int swigValue) {
		for (AsynchroneRequestStatus asynchroneRequestStatus : AsynchroneRequestStatus.values()) {
			if (swigValue == asynchroneRequestStatus.getSwigValue()) {
				return asynchroneRequestStatus;
			}
		}

		return null;
	}

}