package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum DatasetOpenMode implements SwigIntegerValue {

	/**
	 * GA_ReadOnly : flag used for opening a dataset in read-only mode with gdal.Open()
	 */
	READ_ONLY("GA_ReadOnly"),
	/**
	 * GA_Update : flag used for opening a dataset in update mode with gdal.Open()
	 */
	UPDATE("GA_Update");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private DatasetOpenMode(String value) {
		this.name = value;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case READ_ONLY:
				return gdalconst.GA_ReadOnly;
			case UPDATE:
				return gdalconst.GA_Update;
			default:
				return gdalconst.GA_ReadOnly;
		}
	}

	/**
	 * Get this DatasetOpenMode by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the DatasetOpenMode which corresponds to the name.
	 */
	public static DatasetOpenMode getConstantByName(String name) {
		for (DatasetOpenMode datasetOpenMode : DatasetOpenMode.values()) {
			if (name.equalsIgnoreCase(datasetOpenMode.name)) {
				return datasetOpenMode;
			}
		}

		return null;
	}

	/**
	 * Get this DatasetOpenMode by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the DatasetOpenMode which corresponds to the value.
	 */
	public static DatasetOpenMode getConstantByValue(int swigValue) {
		for (DatasetOpenMode datasetOpenMode : DatasetOpenMode.values()) {
			if (swigValue == datasetOpenMode.getSwigValue()) {
				return datasetOpenMode;
			}
		}

		return null;
	}
}