package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigStringValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum DriverCreateAttribute implements SwigStringValue {

	CREATE("GDAL_DCAP_CREATE"),
	CREATE_COPY("GDAL_DCAP_CREATECOPY"),
	VIRTUAL_IO("GDAL_DCAP_VIRTUALIO");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private DriverCreateAttribute(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public String getSwigStringValue() {
		switch (this) {
			case CREATE:
				return gdalconst.GDAL_DCAP_CREATE;
			case CREATE_COPY:
				return gdalconst.GDAL_DCAP_CREATECOPY;
			case VIRTUAL_IO:
				return gdalconst.GDAL_DCAP_VIRTUALIO;
			default:
				return gdalconst.GDAL_DCAP_CREATE;

		}
	}

	/**
	 * Get this DriverCreateAttribute by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the DriverCreateAttribute which corresponds to the name.
	 */
	public static DriverCreateAttribute getConstantByName(String name) {
		for (DriverCreateAttribute driverCreateAttribute : DriverCreateAttribute.values()) {
			if (name.equalsIgnoreCase(driverCreateAttribute.name)) {
				return driverCreateAttribute;
			}
		}

		return null;
	}

	/**
	 * Get this DriverCreateAttribute by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the DriverCreateAttribute which corresponds to the value.
	 */
	public static DriverCreateAttribute getConstantByValue(String swigValue) {
		for (DriverCreateAttribute driverCreateAttribute : DriverCreateAttribute.values()) {
			if (swigValue.equalsIgnoreCase(driverCreateAttribute.getSwigStringValue())) {
				return driverCreateAttribute;
			}
		}

		return null;
	}
}