package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigStringValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum DriverMetaData implements SwigStringValue {

	CREATION_DATA_TYPES("GDAL_DMD_CREATIONDATATYPES"),
	CREATION_OPTION_LIST("GDAL_DMD_CREATIONOPTIONLIST"),
	EXTENSION("GDAL_DMD_EXTENSION"),
	HELP_TOPIC("GDAL_DMD_HELPTOPIC"),
	LONG_NAME("GDAL_DMD_LONGNAME"),
	MIME_TYPE("GDAL_DMD_MIMETYPE"),
	SUB_DATASETS("GDAL_DMD_SUBDATASETS");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private DriverMetaData(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public String getSwigStringValue() {
		switch (this) {
			case CREATION_DATA_TYPES:
				return gdalconst.GDAL_DMD_CREATIONDATATYPES;
			case CREATION_OPTION_LIST:
				return gdalconst.GDAL_DMD_CREATIONOPTIONLIST;
			case EXTENSION:
				return gdalconst.GDAL_DMD_EXTENSION;
			case HELP_TOPIC:
				return gdalconst.GDAL_DMD_HELPTOPIC;
			case LONG_NAME:
				return gdalconst.GDAL_DMD_LONGNAME;
			case MIME_TYPE:
				return gdalconst.GDAL_DMD_MIMETYPE;
			case SUB_DATASETS:
				return gdalconst.GDAL_DMD_SUBDATASETS;
			default:
				return gdalconst.GDAL_DMD_LONGNAME;

		}
	}

	/**
	 * Get this DriverMetaData by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the DriverMetaData which corresponds to the name.
	 */
	public static DriverMetaData getConstantByName(String name) {
		for (DriverMetaData driverMetaData : DriverMetaData.values()) {
			if (name.equalsIgnoreCase(driverMetaData.name)) {
				return driverMetaData;
			}
		}

		return null;
	}

	/**
	 * Get this DriverMetaData by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the DriverMetaData which corresponds to the value.
	 */
	public static DriverMetaData getConstantByValue(String swigValue) {
		for (DriverMetaData driverMetaData : DriverMetaData.values()) {
			if (swigValue.equalsIgnoreCase(driverMetaData.getSwigStringValue())) {
				return driverMetaData;
			}
		}

		return null;
	}

}