package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum ErrorMessage implements SwigIntegerValue {

	/**
	 * CPLE_None == 0 (error code).
	 */
	NONE("CPLE_None"),
	/**
	 * CPLE_AppDefined == 1 (error code).
	 */
	APP_DEFINED("CPLE_AppDefined"),
	/**
	 * CPLE_OutOfMemory == 2 (error code).
	 */
	OUT_OF_MEMORY("CPLE_OutOfMemory"),
	/**
	 * CPLE_FileIO == 3 (error code).
	 */
	FILE_IO("CPLE_FileIO"),
	/**
	 * CPLE_OpenFailed == 4 (error code).
	 */
	OPEN_FAILED("CPLE_OpenFailed"),
	/**
	 * CPLE_IllegalArg == 5 (error code).
	 */
	ILLEGAL_ARG("CPLE_IllegalArg"),
	/**
	 * CPLE_NotSupported == 6 (error code).
	 */
	NOT_SUPPORTED("CPLE_NotSupported"),
	/**
	 * CPLE_AssertionFailed == 7 (error code).
	 */
	ASSERTION_FAILED("CPLE_AssertionFailed"),
	/**
	 * CPLE_NoWriteAccess == 8 (error code).
	 */
	NO_WRITE_ACCESS("CPLE_NoWriteAccess"),
	/**
	 * CPLE_UserInterrupt == 9 (error code).
	 */
	USER_INTERRUPT("CPLE_UserInterrupt");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private ErrorMessage(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case APP_DEFINED:
				return gdalconst.CPLE_AppDefined;
			case ASSERTION_FAILED:
				return gdalconst.CPLE_AssertionFailed;
			case FILE_IO:
				return gdalconst.CPLE_FileIO;
			case ILLEGAL_ARG:
				return gdalconst.CPLE_IllegalArg;
			case NONE:
				return gdalconst.CPLE_None;
			case NOT_SUPPORTED:
				return gdalconst.CPLE_NotSupported;
			case NO_WRITE_ACCESS:
				return gdalconst.CPLE_NoWriteAccess;
			case OPEN_FAILED:
				return gdalconst.CPLE_OpenFailed;
			case OUT_OF_MEMORY:
				return gdalconst.CPLE_OutOfMemory;
			case USER_INTERRUPT:
				return gdalconst.CPLE_UserInterrupt;
			default:
				return gdalconst.CPLE_None;
		}
	}

	/**
	 * Get this ErrorMessage by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the ErrorMessage which corresponds to the name.
	 */
	public static ErrorMessage getConstantByName(String name) {
		for (ErrorMessage errorMessage : ErrorMessage.values()) {
			if (name.equalsIgnoreCase(errorMessage.name)) {
				return errorMessage;
			}
		}

		return null;
	}

	/**
	 * Get this ErrorMessage by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the ErrorMessage which corresponds to the value.
	 */
	public static ErrorMessage getConstantByValue(int swigValue) {
		for (ErrorMessage errorMessage : ErrorMessage.values()) {
			if (swigValue == errorMessage.getSwigValue()) {
				return errorMessage;
			}
		}

		return null;
	}
}