package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 *         Used in GDALRasterAttributeTable
 */
public enum FieldType implements SwigIntegerValue {

	INTEGER("GFT_Integer"),
	REAL("GFT_Real"),
	STRING("GFT_String");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private FieldType(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case INTEGER:
				return gdalconst.GFT_Integer;
			case REAL:
				return gdalconst.GFT_Real;
			case STRING:
				return gdalconst.GFT_String;
			default:
				return gdalconst.GFT_String;
		}
	}

	/**
	 * Get this FieldType by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the FieldType which corresponds to the name.
	 */
	public static FieldType getConstantByName(String name) {
		for (FieldType fieldType : FieldType.values()) {
			if (name.equalsIgnoreCase(fieldType.name)) {
				return fieldType;
			}
		}

		return null;
	}

	/**
	 * Get this FieldType by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the FieldType which corresponds to the value.
	 */
	public static FieldType getConstantByValue(int swigValue) {
		for (FieldType fieldType : FieldType.values()) {
			if (swigValue == fieldType.getSwigValue()) {
				return fieldType;
			}
		}

		return null;
	}

}