package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 *         Used in RasterAttributeTable
 * 
 */
public enum FieldUsage implements SwigIntegerValue {

	ALPHA("GFU_Alpha"),
	ALPHA_MAX("GFU_AlphaMax"),
	ALPHA_MIN("GFU_AlphaMin"),
	BLUE("GFU_Blue"),
	BLUE_MAX("GFU_BlueMax"),
	BLUE_MIN("GFU_BlueMin"),
	GENERIC("GFU_Generic"),
	GREEN("GFU_Green"),
	GREEN_MAX("GFU_GreenMax"),
	GREEN_MIN("GFU_GreenMin"),
	MAX("GFU_Max"),
	MAX_COUNT("GFU_MaxCount"),
	MIN("GFU_Min"),
	MIN_MAX("GFU_MinMax"),
	NAME("GFU_Name"),
	PIXEL_COUNT("GFU_PixelCount"),
	RED("GFU_Red"),
	RED_MAX("GFU_RedMax"),
	RED_MIN("GFU_RedMin");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private FieldUsage(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case ALPHA:
				return gdalconst.GFU_Alpha;
			case ALPHA_MAX:
				return gdalconst.GFU_AlphaMax;
			case ALPHA_MIN:
				return gdalconst.GFU_AlphaMin;
			case BLUE:
				return gdalconst.GFU_Blue;
			case BLUE_MAX:
				return gdalconst.GFU_BlueMax;
			case BLUE_MIN:
				return gdalconst.GFU_BlueMin;
			case GENERIC:
				return gdalconst.GFU_Generic;
			case GREEN:
				return gdalconst.GFU_Green;
			case GREEN_MAX:
				return gdalconst.GFU_GreenMax;
			case GREEN_MIN:
				return gdalconst.GFU_GreenMin;
			case MAX:
				return gdalconst.GFU_Max;
			case MAX_COUNT:
				return gdalconst.GFU_MaxCount;
			case MIN:
				return gdalconst.GFU_Min;
			case MIN_MAX:
				return gdalconst.GFU_MinMax;
			case NAME:
				return gdalconst.GFU_Name;
			case PIXEL_COUNT:
				return gdalconst.GFU_PixelCount;
			case RED:
				return gdalconst.GFU_Red;
			case RED_MAX:
				return gdalconst.GFU_RedMax;
			case RED_MIN:
				return gdalconst.GFU_RedMin;
			default:
				return gdalconst.GFU_Name;
		}
	}

	/**
	 * Get this FieldUsage by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the FieldUsage which corresponds to the name.
	 */
	public static FieldUsage getConstantByName(String name) {
		for (FieldUsage fieldUsage : FieldUsage.values()) {
			if (name.equalsIgnoreCase(fieldUsage.name)) {
				return fieldUsage;
			}
		}

		return null;
	}

	/**
	 * Get this FieldUsage by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the FieldUsage which corresponds to the value.
	 */
	public static FieldUsage getConstantByValue(int swigValue) {
		for (FieldUsage fieldUsage : FieldUsage.values()) {
			if (swigValue == fieldUsage.getSwigValue()) {
				return fieldUsage;
			}
		}

		return null;
	}

}