package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum GjpXmlNodeType implements SwigIntegerValue {

	/**
	 * CXT_Attribute(2) : node is an attribute.
	 */
	ATTRIBUTE("CXT_Attribute"),
	/**
	 * CXT_Comment(3) : node is a XML comment.
	 */
	COMMENT("CXT_Comment"),
	/**
	 * CTX_Element(0) : node is an element.
	 */
	ELEMENT("CTX_Element"),
	/**
	 * CXT_Literal(4) : node is a special literal.
	 */
	LITERAL("CXT_Literal"),
	/**
	 * CXT_Text(1) : node is a raw text value
	 */
	TEXT("CXT_Text");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private GjpXmlNodeType(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case ATTRIBUTE:
				return gdalconst.CXT_Attribute;
			case COMMENT:
				return gdalconst.CXT_Comment;
			case ELEMENT:
				return gdalconst.CXT_Element;
			case LITERAL:
				return gdalconst.CXT_Literal;
			case TEXT:
				return gdalconst.CXT_Text;
			default:
				return gdalconst.CXT_Text;

		}
	}

	/**
	 * Get this GjpXmlNodeType by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the GjpXmlNodeType which corresponds to the name.
	 */
	public static GjpXmlNodeType getConstantByName(String name) {
		for (GjpXmlNodeType gjpXmlNodeType : GjpXmlNodeType.values()) {
			if (name.equalsIgnoreCase(gjpXmlNodeType.name)) {
				return gjpXmlNodeType;
			}
		}

		return null;
	}

	/**
	 * Get this GjpXmlNodeType by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the GjpXmlNodeType which corresponds to the value.
	 */
	public static GjpXmlNodeType getConstantByValue(int swigValue) {
		for (GjpXmlNodeType gjpXmlNodeType : GjpXmlNodeType.values()) {
			if (swigValue == gjpXmlNodeType.getSwigValue()) {
				return gjpXmlNodeType;
			}
		}

		return null;
	}
}