package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum MessageCategory implements SwigIntegerValue {

	/**
	 * No error == 0 (message class and error return code).
	 */
	NONE("CE_None"),
	/**
	 * Debug error == 1 (message class).
	 */
	DEBUG("CE_Debug"),
	/**
	 * Warning error == 2 (message class and error return code).
	 */
	WARNING("CE_Warning"),
	/**
	 * Failure error == 3 (message class and error return code).
	 */
	FAILURE("CE_Failure"),
	/**
	 * Fatal error == 4 (message class).
	 */
	FATAL("CE_Fatal");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private MessageCategory(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case DEBUG:
				return gdalconst.CE_Debug;
			case FAILURE:
				return gdalconst.CE_Failure;
			case FATAL:
				return gdalconst.CE_Fatal;
			case NONE:
				return gdalconst.CE_None;
			case WARNING:
				return gdalconst.CE_Warning;
			default:
				return gdalconst.CE_None;
		}
	}

	/**
	 * Get this MessageCategory by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the MessageCategory which corresponds to the name.
	 */
	public static MessageCategory getConstantByName(String name) {
		for (MessageCategory messageCategory : MessageCategory.values()) {
			if (name.equalsIgnoreCase(messageCategory.name)) {
				return messageCategory;
			}
		}

		return null;
	}

	/**
	 * Get this MessageCategory by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the MessageCategory which corresponds to the value.
	 */
	public static MessageCategory getConstantByValue(int swigValue) {
		for (MessageCategory messageCategory : MessageCategory.values()) {
			if (swigValue == messageCategory.getSwigValue()) {
				return messageCategory;
			}
		}

		return null;
	}
}