package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum PaletteInterpretation implements SwigIntegerValue {

	/**
	 * GPI_CMYK(2) (palette interpretation). Cyan, Magenta, Yellow and Black (in c1, c2, c3 and c4)
	 */
	CYAN_MAGENTA_YELLOW_BLACK("GPI_CMYK"),
	/**
	 * GPI_Gray(0) (palette interpretation). Grayscale (in GDALColorEntry.c1)
	 */
	GRAYSCALE("GPI_Gray"),
	/**
	 * GPI_HLS(3) (palette interpretation). Hue, Lightness and Saturation (in c1, c2, and c3)
	 */
	HUE_LIGHTNESS_SATURATION("GPI_HLS"),
	/**
	 * GPI_RGB(1) (palette interpretation). Red, Green, Blue and Alpha in (in c1, c2, c3 and c4)
	 */
	RED_GREEN_BLUE_ALPHA("GPI_RGB");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private PaletteInterpretation(String name) {

		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case CYAN_MAGENTA_YELLOW_BLACK:
				return gdalconst.GPI_CMYK;
			case GRAYSCALE:
				return gdalconst.GPI_Gray;
			case HUE_LIGHTNESS_SATURATION:
				return gdalconst.GPI_HLS;
			case RED_GREEN_BLUE_ALPHA:
				return gdalconst.GPI_RGB;
			default:
				return gdalconst.GPI_RGB;
		}
	}

	/**
	 * Get this PaletteInterpretation by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the PaletteInterpretation which corresponds to the name.
	 */
	public static PaletteInterpretation getConstantByName(String name) {
		for (PaletteInterpretation paletteInterpretation : PaletteInterpretation.values()) {
			if (name.equalsIgnoreCase(paletteInterpretation.name)) {
				return paletteInterpretation;
			}
		}

		return null;
	}

	/**
	 * Get this PaletteInterpretation by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the PaletteInterpretation which corresponds to the value.
	 */
	public static PaletteInterpretation getConstantByValue(int swigValue) {
		for (PaletteInterpretation paletteInterpretation : PaletteInterpretation.values()) {
			if (swigValue == paletteInterpretation.getSwigValue()) {
				return paletteInterpretation;
			}
		}

		return null;
	}
}